@@ -8,6 +8,7 @@ from indico_install.package import package
 from indico_install.encoder import encode, decode
 from indico_install.updraft import updraft
 from indico_install.inspect import inspect
+from indico_install.snapshot import snapshot
 
 command_groups = [
     pull,
@@ -25,6 +26,7 @@ command_groups = [
     decode,
     updraft,
     upload,
+    snapshot,
 ]
 
 
