@@ -5,7 +5,7 @@ from datetime import datetime
 
 from click import prompt, secho
 
-from indico_install.config import REMOTE_TEMPLATES_PATH, merge_dicts, yaml
+from indico_install.config import IMAGE_REGISTRY, REMOTE_TEMPLATES_PATH, merge_dicts, yaml
 from indico_install.utils import (
     current_user,
     diff_dicts,
@@ -74,7 +74,7 @@ def _list_versions():
 def list_backups():
     out = run_cmd(
         "kubectl get cm --no-headers -o custom-columns=Name:.metadata.name 2>&1 "
-        "| grep {TRACKER_CONFIGMAP_BACKUP}",
+        f"| grep {TRACKER_CONFIGMAP_BACKUP}",
         silent=True,
     )
     return [] if not out else sorted(out.splitlines(), reverse=True)
@@ -142,7 +142,7 @@ class ClusterManager(object):
 
     @property
     def registry(self):
-        return self.cluster_config.get("dockerRegistry", "gcr.io/new-indico") + "/"
+        return self.cluster_config.get("dockerRegistry", f"{IMAGE_REGISTRY}") + "/"
 
     @classmethod
     def diff(cls, version_1, version_2):
