@@ -71,12 +71,15 @@ def import_existing_objects(dependency):
             obj_name = obj['metadata']['name']
             obj_namespace = obj['metadata'].get('namespace', 'default')
             output = run_cmd(
-                f"kubectl get {obj_kind} {obj_name} -n {obj_namespace}"
+                f"kubectl get {obj_kind} {obj_name} -n {obj_namespace}", silent=True
             )
             if len(output) > 0:
-                run_cmd(f"kubectl annotate {obj_kind} {obj_name} -n {obj_namespace} meta.helm.sh/release-name={name}")
-                run_cmd(f"kubectl annotate {obj_kind} {obj_name} -n {obj_namespace} meta.helm.sh/release-namespace={namespace}")
-                run_cmd(f"kubectl label {obj_kind} {obj_name} -n {obj_namespace} app.kubernetes.io/managed-by=Helm")
+                click.secho(
+                    f"Found existing object {obj_name} of kind {obj_kind} in namespace {obj_namespace}, importing into Helm"
+                )
+                run_cmd(f"kubectl annotate {obj_kind} {obj_name} -n {obj_namespace} meta.helm.sh/release-name={name}", silent=True)
+                run_cmd(f"kubectl annotate {obj_kind} {obj_name} -n {obj_namespace} meta.helm.sh/release-namespace={namespace}", silent=True)
+                run_cmd(f"kubectl label {obj_kind} {obj_name} -n {obj_namespace} app.kubernetes.io/managed-by=Helm", silent=True)
     
 
 def release_exists(dependency):
