@@ -7,7 +7,7 @@ from indico_install.utils import current_user, run_cmd
 from indico_install.infra.gke.env_confs import environments
 
 DEFAULT_NODE_CONFIGS = {
-    "image-type": "UBUNTU",
+    "image-type": "UBUNTU_CONTAINERD",
     "disk-type": "pd-standard",
     "scopes": (
         '"https://www.googleapis.com/auth/devstorage.read_only",'
@@ -187,7 +187,7 @@ def create_nodepools(
 @click.option(
     "--version",
     help="GKE Cluster version or version family to use",
-    default="1.19",
+    default="1.20",
     show_default=True,
 )
 @click.option(
@@ -246,7 +246,7 @@ def create_cluster(
 
     name = name.lower()
     env_conf = environments[environment]
-    assert env_conf["abbrev"] in name
+    assert env_conf["abbrev"] in name, f"Please prefix your cluster name with one of the allowed prefixes: {[env.get('abbrev', '') for env in environments.values()]}"
 
     size = int(size)
     assert size > 0
