@@ -160,8 +160,8 @@ def down(ctx, cluster_name):
     # 0. Track current pool settings
     for pool in node_pools:
         if pool.get("autoscaling", {}).get("enabled"):
-            #since we are no longer using pvm nodes, we only use autoscaling groups. These need to start with an initial count.
-            size = pool["initialNodeCount"]
+            #dev clusters still use PVM nodes, so this value might not be set
+            size = pool.get("initialNodeCount", 0)
             autoscale = {"min": 0, "max": pool["autoscaling"]["maxNodeCount"]}
         else:
             size = pool["initialNodeCount"]
