@@ -8,7 +8,7 @@ from indico_install.cluster_manager import (
     ClusterManager,
     get_deployed_frontend,
 )
-from indico_install.config import SERVICES_YAML, ConfigsHolder
+from indico_install.config import SERVICES_YAML, IMAGE_REGISTRY, ConfigsHolder
 from indico_install.helm.apply import apply
 from indico_install.helm.render import render, resolve_all
 from indico_install.kube.svc.restart import restart
@@ -54,8 +54,8 @@ def push_all(ctx, *, yes, forwarded=True):
         if yes or confirm("Push new image?"):
             secho(
                 run_cmd(
-                    f"kubectl set image --record=true {resource}/{deployment} "
-                    f"{deployment}=gcr.io/new-indico/{saved_image}"
+                    f"kubectl set image {resource}/{deployment} "
+                    f"{deployment}={IMAGE_REGISTRY}/{saved_image}"
                 ),
                 fg="green",
             )
@@ -119,8 +119,8 @@ def push_svc(ctx, svc, *, yes, image=None, exclude=None):
         if yes or confirm("Push new image?"):
             secho(
                 run_cmd(
-                    "kubectl set image --record=true "
-                    f"{resource_type}/{resource} {resource}=gcr.io/new-indico/{image}",
+                    "kubectl set image "
+                    f"{resource_type}/{resource} {resource}={IMAGE_REGISTRY}/{image}",
                     silent=True,
                 )
             )
@@ -163,8 +163,8 @@ def push_image(ctx, image_name, *, yes, image=None):
         if yes or confirm("Push new image?"):
             secho(
                 run_cmd(
-                    "kubectl set image --record=true "
-                    f"{resource_type}/{resource} {resource}=gcr.io/new-indico/{image}",
+                    "kubectl set image "
+                    f"{resource_type}/{resource} {resource}={IMAGE_REGISTRY}/{image}",
                     silent=True,
                 )
             )
