@@ -42,11 +42,11 @@ def get_app_hashes():
 
 def get_non_matching_images(configs, only_first=False):
     output = run_cmd(
-        "kubectl get deploy -o wide  | grep indico | awk '{print $1\"=\"$7s}'",
+        "kubectl get deploy -o wide -A | grep indico | awk '{print $2\"=\"$8s}'",
         silent=True,
     )
     images = {
-        x[0]: ("deployment", x[1])
+        x[0]: ("deployment", x[1].split(",")[0])
         for x in [y.split("=") for y in output.split("\n") if y.strip()]
     }
 
@@ -180,14 +180,19 @@ def find_names(svc_type, service, contains=True):
 def get_resources(svc_type, service):
     out = run_cmd(
         "kubectl get %s %s -o=jsonpath='{.spec.template.spec.containers[*].resources}"
-        % (svc_type, service),
+        % (svc_type, service)
     )
     return json.loads(out)
 
+
 def patch_resources(svc_type, service, resources):
-    patch_command = json.dumps([{
-        "op": "replace",
-        "path": "/spec/template/spec/containers/0/resources",
-        "value": resources
-    }])
+    patch_command = json.dumps(
+        [
+            {
+                "op": "replace",
+                "path": "/spec/template/spec/containers/0/resources",
+                "value": resources,
+            }
+        ]
+    )
     patch_command = f"k patch {svc_type} {service} --type='json' -p='{patch_command}'"
